Module data

Module data 

SRT data packet — draft-sharabayko-srt-01 3.1, Figure 3.

word0  0|                Packet Sequence Number (31)                 |
word1  PP|O|KK|R|                Message Number (26)                 |
word2                          Timestamp (32)
word3                    Destination Socket ID (32)
rest                              Data

Structs

DataPacket
An SRT data packet (draft-sharabayko-srt-01 3.1, Figure 3).

Enums

EncryptionKeyField
KK: Key-based Encryption Flag — whether/how the Data field is encrypted (draft-sharabayko-srt-01 3.1, 6). 11b is reserved for control packets (Key Material’s own KK field, 3.2.2) and should not appear on a data packet, but is decoded rather than rejected.
PacketPosition
PP: Packet Position Flag — position of the data packet in its message (draft-sharabayko-srt-01 3.1).