pub struct DropReqPacket {
pub message_number: u32,
pub timestamp: u32,
pub dest_socket_id: u32,
pub first_seq: u32,
pub last_seq: u32,
}Expand description
Message Drop Request control packet (3.2.9, Figure 18).
Fields
message_number: u32The message number requested to be dropped (0 if the sender no
longer has the packets and cannot restore it).
timestamp: u32Timestamp (3).
dest_socket_id: u32Destination Socket ID (3).
first_seq: u32First Packet Sequence Number of the range to drop.
last_seq: u32Last Packet Sequence Number of the range to drop.